@@ -2,7 +2,8 @@ ci.sc <- function(means=NULL, s.anova=NULL, c.weights=NULL, n=NULL, N=NULL,
 Psi=NULL, ncp=NULL, conf.level=.95, alpha.lower=NULL, alpha.upper=NULL, df.error=NULL, ...)
 {
 
-if(sum(c.weights[c.weights>0])>1) stop("Please use fractions to specify the contrast weights")
+if(!identical(sum(c.weights[c.weights>0]), 1)) stop("Please use fractions to specify the contrast weights")
+if(!identical(round(sum(c.weights), 5), 0)) stop("The sum of the contrast weights ('c.weights') should equal zero.")
   
 if(length(n)==1) 
 {
@@ -10,8 +11,8 @@ n <- rep(n, length(means))
 }
 
 if(length(n)!=length(c.weights)) stop("The lengths of 'n' and 'c.weights' differ, which should not be the case.")
-if(!(sum(c.weights)==0)) stop("The sum of the contrast weights ('c.weights') should equal zero.")
 
+ 
 part.of.se <- sqrt(sum((c.weights^2)/n))
 
 if(!is.null(Psi))
@@ -61,7 +62,7 @@ Lims <- conf.limits.nct(ncp=lambda, df=df.2, conf.level = NULL, alpha.lower = al
 Result <- list(Lower.Conf.Limit.Standardized.Contrast = Lims$Lower.Limit*part.of.se, Standardized.contrast = psi, 
         Upper.Conf.Limit.Standardized.Contrast = Lims$Upper.Limit*part.of.se)
         
-print(paste("The", 1 - (alpha.lower + alpha.upper), "confidence limits for the standardized contrast are given as:"))
+# print(paste("The", 1 - (alpha.lower + alpha.upper), "confidence limits for the standardized contrast are given as:"))
 
 return(Result)
 }
